@@ -4,15 +4,17 @@ import logging as _logging
 
 from . import spells, types
 from ._common import DEFAULT_PRIORITY, from_date, to_date
-from ._group import MetadataCheck, TodoGroup
+from ._group import DateRange, DescFilter, MetadataFilter, TodoGroup
 from ._magic import MagicTodoMixin
 from ._todo import Todo
 
 
 __all__ = [
     "DEFAULT_PRIORITY",
+    "DateRange",
+    "DescFilter",
     "MagicTodoMixin",
-    "MetadataCheck",
+    "MetadataFilter",
     "Todo",
     "TodoGroup",
     "from_date",
@@ -23,6 +25,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.9.5"
+__version__ = "0.10.0"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
